@@ -1,12 +1,10 @@
 #!/usr/bin/env python
 
 import sys
-import os
 import homewindow
 
 from PyQt4.QtGui import QApplication
 
-os.system("dbus-send --system --type=method_call --dest=com.nokia.icd /com/nokia/icd com.nokia.icd.connect string:\'[ANY]\' uint32:0")
 app = QApplication(sys.argv)
 app.setOrganizationName("Stuart Howarth")
 app.setOrganizationDomain("marxianthecoder.blogspot.com")
