@@ -523,22 +523,50 @@ class SearchDialog(QDialog, Ui_searchDialog):
         searchDict = {"Date published": "published", "Relevance": "relevance", "View count": "viewCount", "Rating": "rating"}
         searchOrder = searchDict.get(unicode(self.searchOrderButton.valueText()))
         if searchString.startswith("http://www.youtube.com/watch?v="):
-            from videoinfowindow import VideoInfoWindow
-            try:
-                videoId = searchString.split("=") [1].split("&")[0]
-                video = youtubeservice.YouTubeDataService.getVideoEntry(videoId)
-                videoInfoWindow = VideoInfoWindow(self, video)
-            except:
-                QMaemo5InformationBox.information(self, "Unable to find YouTube video. Please check the URL")
+            self.goToVideo(searchString)
         else:
-            if searchString in SearchSettings.recentSearches:
-                SearchSettings.recentSearches.removeAll(searchString)
-            if SearchSettings.recentSearches.count() > 30:
-                SearchSettings.recentSearches.removeAt(30)
-            SearchSettings.recentSearches.prepend(searchString)
-            searchWindow = cutetubewindows.SearchResultsWindow(self, searchString, searchOrder, self.username)
+            self.getSearchResults(searchString, searchOrder)
+            
+    def goToVideo(self, url):
+        """
+        Takes the user directly to the Video Info window.
+        """
+        from videoinfowindow import VideoInfoWindow
+        try:
+            videoId = url.split("=") [1].split("&")[0]
+            video = youtubeservice.YouTubeDataService.getVideoEntry(videoId)
+            restriction = youtubeservice.YouTubeDataService.getVideoRestrictions(video)
+            if restriction == None:
+                videoInfoWindow = VideoInfoWindow(self, video)
+                self.connect(videoInfoWindow, SIGNAL("queueChanged(int)"), self.queueChanged)
+                self.connect(videoInfoWindow, SIGNAL("downloadsChanged(int)"), self.downloadsChanged)
+            else:
+                QMaemo5InformationBox.information(self, "Video not available: %s" % restriction)
+        except:
+            QMaemo5InformationBox.information(self, "Unable to find YouTube video. Please check the URL")
+            
+    def getSearchResults(self, searchString, searchOrder):
+        """
+        Creates a Search Results window.
+        """
+        if searchString in SearchSettings.recentSearches:
+            SearchSettings.recentSearches.removeAll(searchString)
+        if SearchSettings.recentSearches.count() > 30:
+            SearchSettings.recentSearches.removeAt(30)
+        SearchSettings.recentSearches.prepend(searchString)
+        searchWindow = cutetubewindows.SearchResultsWindow(self, searchString, searchOrder, self.username)
         
-    
+    def queueChanged(self, queueLength):
+        """
+        Emits the queueChanged(int) signal to the parent window.
+        """
+        self.emit(SIGNAL("queueChanged(int)"), queueLength)
+        
+    def downloadsChanged(self,  taskQueueLength):
+        """
+        Emits the downloadsChanged(int) signal to the parent window.
+        """
+        self.emit(SIGNAL("downloadsChanged(int)"), taskQueueLength)
 
 class SettingsDialog(QDialog):
     """
@@ -1156,7 +1184,7 @@ class ShareViaTwitterDialog(QDialog):
             self.toggleBusy(True)
             try:
                 Twitter.postMessage(message)
-                QMaemo5InformationBox.information(self, "Your message has been posted to Twitter")
+                QMaemo5InformationBox.information(self, "Your video and message have been posted to Twitter")
                 self.accept()
             except Exception, e:
                 CutetubeLog.logException("Unable to post message to Twitter: ")
@@ -1253,7 +1281,8 @@ class ShareViaFacebookDialog(QDialog):
         """
         QDialog.__init__(self, parent)
         self.setWindowTitle("Share Via Facebook")
-        self.messageEdit = QTextEdit(videoUrl, self)
+        self.videoUrl = videoUrl
+        self.messageEdit = QTextEdit(self)
         self.submitButton = QPushButton("Submit", self)
         self.connect(QApplication.desktop(), SIGNAL("resized(int)"), self.orientationChanged)
         self.orientationChanged()
@@ -1290,8 +1319,8 @@ class ShareViaFacebookDialog(QDialog):
         if message != "":
             self.toggleBusy(True)
             try:
-                Facebook.postMessage(message)
-                QMaemo5InformationBox.information(self, "Your message has been posted to Facebook")
+                Facebook.postMessage(message, self.videoUrl)
+                QMaemo5InformationBox.information(self, "Your video and message have been posted to Facebook")
                 self.accept()
             except Exception, e:
                 CutetubeLog.logException("Unable to post message to Facebook: ")
