@@ -187,7 +187,7 @@ class CutetubeWindows(QMainWindow, Ui_CutetubeWindows):
         Shows the 'more' button to enable the user to 
         get more results.
         """
-        if self.yt.isFinished() and self.results >= 25 and scrollBarPos > (self.results - 10) * 79:
+        if self.yt.isFinished() and self.yt.results < self.yt.totalResults and scrollBarPos > (self.yt.results - 10) * 79:
             self.moreButton.setVisible(True)
         else:
             self.moreButton.setVisible(False)
@@ -210,11 +210,14 @@ class CutetubeWindows(QMainWindow, Ui_CutetubeWindows):
         self.loadData()
 
     def addVideo(self, videoData):
+        """
+        Appends a video item to the listWidget.
+        """
         size = QSize()
         size.setHeight(79)
         item = QListWidgetItem()
         item.setSizeHint(size)
-        itemWidget = customwidgets.VideoItemWidget(videoData[0], videoData[1])
+        itemWidget = customwidgets.VideoItemWidget(videoData)
         if self.actionPencil.isChecked():
             itemWidget.showCheckBox()
             item.setFlags(Qt.ItemIsEnabled)
@@ -224,7 +227,18 @@ class CutetubeWindows(QMainWindow, Ui_CutetubeWindows):
         author = itemWidget.authorLabel.text()
         if not title.contains(self.lineFilter.text(), Qt.CaseInsensitive) and not author.contains(self.lineFilter.text(), Qt.CaseInsensitive):
                 self.listWidget.setItemHidden(item, True)
-        self.results += 1
+                
+    def addVideoThumbnail(self, videoData):
+        """
+        Adds the video thumbnail to the appropriate video item in the listWidget.
+        """
+        row, thumbnail = videoData
+        item = self.listWidget.item(row)
+        thumbLabel = self.listWidget.itemWidget(item).thumbLabel
+        try:
+            thumbLabel.setPixmap(thumbnail) 
+        except:
+            thumbLabel.setPixmap(QPixmap(":/images/ui-images/thumbnail.png"))
 
     @pyqtSignature("QListWidgetItem*")
     def on_listWidget_itemClicked(self, item):
@@ -442,11 +456,11 @@ class MostRecentWindow(CutetubeWindows):
             self.actionAddToPlaylist.setVisible(True)
         self.actionPencil.setVisible(True)
         self.pencilList = []
-        self.results = 0
         self.show()
         self.videoFeed = "http://gdata.youtube.com/feeds/api/standardfeeds/most_recent"
         self.yt = youtubeservice.YouTubeVideoFeed(self, self.videoFeed)
         self.connect(self.yt, SIGNAL("dataLoaded(PyQt_PyObject)"), self.addVideo)
+        self.connect(self.yt, SIGNAL("thumbnailLoaded(PyQt_PyObject)"), self.addVideoThumbnail)
         self.connect(self.yt, SIGNAL("feedCompleted(bool)"), self.toggleBusy)   
         self.connect(self.listWidget.verticalScrollBar(), SIGNAL("valueChanged(int)"), self.getMoreResults)
         self.loadData()
@@ -468,11 +482,11 @@ class MostViewedWindow(CutetubeWindows):
             self.actionAddToPlaylist.setVisible(True)
         self.actionPencil.setVisible(True)
         self.pencilList = []
-        self.results = 0
         self.show()
         self.videoFeed = "http://gdata.youtube.com/feeds/api/standardfeeds/most_viewed?time=today"
         self.yt = youtubeservice.YouTubeVideoFeed(self, self.videoFeed)
         self.connect(self.yt, SIGNAL("dataLoaded(PyQt_PyObject)"), self.addVideo)
+        self.connect(self.yt, SIGNAL("thumbnailLoaded(PyQt_PyObject)"), self.addVideoThumbnail)
         self.connect(self.yt, SIGNAL("feedCompleted(bool)"), self.toggleBusy)        
         self.connect(self.listWidget.verticalScrollBar(), SIGNAL("valueChanged(int)"), self.getMoreResults)
         self.loadData()
@@ -495,7 +509,6 @@ class SearchResultsWindow(CutetubeWindows):
         self.actionPencil.setVisible(True)
         self.searchString = searchString
         self.pencilList = []
-        self.results = 0
         self.info = False
         self.show() 
         searchTerms = self.searchString.replace(" ", "+")
@@ -506,6 +519,7 @@ class SearchResultsWindow(CutetubeWindows):
             self.videoFeed = "http://gdata.youtube.com/feeds/api/videos?author=%s&vq=%s&orderby=%s" % (username, searchTerms, searchOrder)
         self.yt = youtubeservice.YouTubeVideoFeed(self, self.videoFeed)
         self.connect(self.yt, SIGNAL("dataLoaded(PyQt_PyObject)"), self.addVideo)
+        self.connect(self.yt, SIGNAL("thumbnailLoaded(PyQt_PyObject)"), self.addVideoThumbnail)
         self.connect(self.yt, SIGNAL("feedCompleted(bool)"), self.toggleBusyandCheckResults)       
         self.connect(self.listWidget.verticalScrollBar(), SIGNAL("valueChanged(int)"), self.getMoreResults) 
         self.loadData()
@@ -519,7 +533,7 @@ class SearchResultsWindow(CutetubeWindows):
         size.setHeight(79)
         item = QListWidgetItem()
         item.setSizeHint(size)
-        itemWidget = customwidgets.VideoItemWidget(videoData[0], videoData[1])
+        itemWidget = customwidgets.VideoItemWidget(videoData)
         if self.actionPencil.isChecked():
             itemWidget.showCheckBox()
             item.setFlags(Qt.ItemIsEnabled)
@@ -527,7 +541,6 @@ class SearchResultsWindow(CutetubeWindows):
         self.listWidget.setItemWidget(item, itemWidget)
         title = itemWidget.titleLabel.text()
         author = itemWidget.authorLabel.text()
-        self.results += 1
         if not self.info:
             QMaemo5InformationBox.information(self,  "Showing results for \'%s\'" % self.searchString)
             self.info = True
@@ -538,7 +551,7 @@ class SearchResultsWindow(CutetubeWindows):
         """
         self.setAttribute(Qt.WA_Maemo5ShowProgressIndicator, isBusy)
         if not (self.info or isBusy):
-            if self.results == 0:
+            if self.yt.results == 0:
                 QMaemo5InformationBox.information(self,  "No results found for \'%s\'" % self.searchString)
             self.info == True
 
@@ -562,11 +575,11 @@ class UploadsWindow(CutetubeWindows):
         self.actionDeleteVideo.setVisible(True)
         self.actionPencil.setVisible(True)
         self.pencilList = []
-        self.results = 0
         self.show()
         self.videoFeed = "http://gdata.youtube.com/feeds/api/users/default/uploads"
         self.yt = youtubeservice.YouTubeVideoFeed(self, self.videoFeed)
         self.connect(self.yt, SIGNAL("dataLoaded(PyQt_PyObject)"), self.addVideo)
+        self.connect(self.yt, SIGNAL("thumbnailLoaded(PyQt_PyObject)"), self.addVideoThumbnail)
         self.connect(self.yt, SIGNAL("feedCompleted(bool)"), self.toggleBusy)  
         self.connect(self.listWidget.verticalScrollBar(), SIGNAL("valueChanged(int)"), self.getMoreResults)      
         self.loadData()
@@ -601,11 +614,11 @@ class UserWindow(CutetubeWindows):
             self.actionAddToPlaylist.setVisible(True)
         self.actionPencil.setVisible(True)
         self.pencilList = []
-        self.results = 0
         self.show()
         self.videoFeed = "http://gdata.youtube.com/feeds/api/users/%s/uploads" % self.username
         self.yt = youtubeservice.YouTubeVideoFeed(self, self.videoFeed)
         self.connect(self.yt, SIGNAL("dataLoaded(PyQt_PyObject)"), self.addVideo)
+        self.connect(self.yt, SIGNAL("thumbnailLoaded(PyQt_PyObject)"), self.addVideoThumbnail)
         self.connect(self.yt, SIGNAL("feedCompleted(bool)"), self.toggleBusy)
         self.connect(self.listWidget.verticalScrollBar(), SIGNAL("valueChanged(int)"), self.getMoreResults)
         self.loadData()
@@ -634,11 +647,11 @@ class RelatedVideosWindow(CutetubeWindows):
         self.actionPencil.setVisible(True)
         self.video = video
         self.pencilList = []
-        self.results = 0
         self.show()
         self.videoFeed = video.link[4].href
         self.yt = youtubeservice.YouTubeVideoFeed(self, self.videoFeed)
         self.connect(self.yt, SIGNAL("dataLoaded(PyQt_PyObject)"), self.addVideo)
+        self.connect(self.yt, SIGNAL("thumbnailLoaded(PyQt_PyObject)"), self.addVideoThumbnail)
         self.connect(self.yt, SIGNAL("feedCompleted(bool)"), self.toggleBusy)        
         self.connect(self.listWidget.verticalScrollBar(), SIGNAL("valueChanged(int)"), self.getMoreResults)
         self.loadData()
@@ -669,11 +682,11 @@ class FavouritesWindow(CutetubeWindows):
         self.actionPencil.setVisible(True)
         self.connect(self.actionRemoveFromFavourites, SIGNAL("triggered()"), self.removeFromFavourites)        
         self.pencilList = []
-        self.results = 0
         self.show()
         self.videoFeed = "http://gdata.youtube.com/feeds/api/users/default/favorites"
         self.yt = youtubeservice.YouTubeVideoFeed(self, self.videoFeed)
         self.connect(self.yt, SIGNAL("dataLoaded(PyQt_PyObject)"), self.addVideo)
+        self.connect(self.yt, SIGNAL("thumbnailLoaded(PyQt_PyObject)"), self.addVideoThumbnail)
         self.connect(self.yt, SIGNAL("feedCompleted(bool)"), self.toggleBusy) 
         self.connect(self.listWidget.verticalScrollBar(), SIGNAL("valueChanged(int)"), self.getMoreResults)
         self.loadData()
@@ -816,11 +829,11 @@ class PlaylistVideosWindow(CutetubeWindows):
         self.actionPencil.setVisible(True)
         self.connect(self.actionRemoveFromPlaylist, SIGNAL("triggered()"), self.removeFromPlaylist)
         self.pencilList = []
-        self.results = 0
         self.show()
         self.videoFeed = "http://gdata.youtube.com/feeds/api/playlists/%s" % playlistId.split("/")[-1]
         self.yt = youtubeservice.YouTubeVideoFeed(self, self.videoFeed)
         self.connect(self.yt, SIGNAL("dataLoaded(PyQt_PyObject)"), self.addVideo)
+        self.connect(self.yt, SIGNAL("thumbnailLoaded(PyQt_PyObject)"), self.addVideoThumbnail)
         self.connect(self.yt, SIGNAL("feedCompleted(bool)"), self.toggleBusy)
         self.connect(self.listWidget.verticalScrollBar(), SIGNAL("valueChanged(int)"), self.getMoreResults)
         self.loadData()
@@ -936,6 +949,8 @@ class PlaybackQueueWindow(CutetubeWindows):
         self.show()
         self.yt = youtubeservice.YouTubeQueueFeed(self)
         self.connect(self.yt, SIGNAL("dataLoaded(PyQt_PyObject)"), self.addVideo)
+        self.connect(self.yt, SIGNAL("thumbnailLoaded(PyQt_PyObject)"), self.addVideoThumbnail)
+        self.connect(self.yt, SIGNAL("feedCompleted(bool)"), self.toggleBusy)
         self.loadData()
         
     def addVideo(self, videoData):
@@ -946,7 +961,7 @@ class PlaybackQueueWindow(CutetubeWindows):
         size.setHeight(79)
         item = QListWidgetItem()
         item.setSizeHint(size)
-        itemWidget = customwidgets.VideoItemWidget(videoData[0], videoData[1])
+        itemWidget = customwidgets.VideoItemWidget(videoData)
         self.listWidget.addItem(item)
         self.listWidget.setItemWidget(item, itemWidget)
         title = itemWidget.titleLabel.text()
@@ -1152,7 +1167,6 @@ class NewSubscriptionVideosWindow(CutetubeWindows):
         self.actionAddToPlaylist.setVisible(True)
         self.actionPencil.setVisible(True)
         self.pencilList = []
-        self.results = 0
         self.show()
         try:
             QMaemo5InformationBox.information(self, "Showing latest videos from your subscriptions")
@@ -1161,6 +1175,7 @@ class NewSubscriptionVideosWindow(CutetubeWindows):
         self.videoFeed = "http://gdata.youtube.com/feeds/api/users/default/newsubscriptionvideos"
         self.yt = youtubeservice.YouTubeVideoFeed(self, self.videoFeed)
         self.connect(self.yt, SIGNAL("dataLoaded(PyQt_PyObject)"), self.addVideo)
+        self.connect(self.yt, SIGNAL("thumbnailLoaded(PyQt_PyObject)"), self.addVideoThumbnail)
         self.connect(self.yt, SIGNAL("feedCompleted(bool)"), self.toggleBusy) 
         self.connect(self.listWidget.verticalScrollBar(), SIGNAL("valueChanged(int)"), self.getMoreResults)
         self.loadData()
@@ -1204,6 +1219,8 @@ class DownloadsWindow(CutetubeWindows):
         self.show()
         self.yt = youtubeservice.YouTubeDownloadQueueFeed(self)
         self.connect(self.yt, SIGNAL("dataLoaded(PyQt_PyObject)"), self.addVideo)
+        self.connect(self.yt, SIGNAL("thumbnailLoaded(PyQt_PyObject)"), self.addVideoThumbnail)
+        self.connect(self.yt, SIGNAL("feedCompleted(bool)"), self.toggleBusy)
         self.loadData()
         for task in youtubeservice.YouTubeVideoDownloader.taskQueue:
             self.connect(task, SIGNAL("downloadUpdated()"), self.updateDownloadStatus)
@@ -1254,7 +1271,7 @@ class DownloadsWindow(CutetubeWindows):
         size.setHeight(79)
         item = QListWidgetItem()
         item.setSizeHint(size)
-        self.itemWidget = customwidgets.VideoDownloadItemWidget(videoData[0], videoData[1])
+        self.itemWidget = customwidgets.VideoDownloadItemWidget(videoData)
         self.listWidget.addItem(item)
         self.listWidget.setItemWidget(item, self.itemWidget)
         row = self.listWidget.row(item)
