@@ -273,6 +273,8 @@ class HomeWindow(QMainWindow, Ui_HomeWindow):
         Raises a SearchDialog.
         """
         searchDialog = cutetubedialogs.SearchDialog(self)
+        self.connect(searchDialog, SIGNAL("queueChanged(int)"), self.queueChanged)
+        self.connect(searchDialog, SIGNAL("downloadsChanged(int)"), self.downloadsChanged)
     
     @pyqtSignature("")
     def on_actionSettings_triggered(self):
