@@ -66,6 +66,8 @@ class MyAccountWindow(QMainWindow, Ui_MyAccountWindow):
         if event.key() not in (Qt.Key_Left, Qt.Key_Right, Qt.Key_Up, Qt.Key_Down, Qt.Key_Backspace, Qt.Key_Return, Qt.Key_Control, Qt.Key_Shift, Qt.Key_Space) and not self.searchDialogRaised:
             self.setSearchDialogRaised(True)
             searchDialog = cutetubedialogs.SearchDialog(self)
+            self.connect(searchDialog, SIGNAL("queueChanged(int)"), self.queueChanged)
+            self.connect(searchDialog, SIGNAL("downloadsChanged(int)"), self.downloadsChanged)
             searchDialog.lineEdit.insert(event.text())
             QTimer.singleShot(1000,  lambda isRaised = False: self.setSearchDialogRaised(isRaised))
         else:
