@@ -16,7 +16,7 @@ import cutetubedialogs
 import cutetubewindows
 import youtubeservice
 import customwidgets
-from cutetubeconfig import VideoSharingSettings
+from cutetubeconfig import VideoSharingSettings, GeneralSettings
 from videoplaybackwindow import VideoPlaybackWindow
 
 class VideoInfoWindow(QMainWindow, Ui_VideoInfoWindow):
@@ -30,6 +30,7 @@ class VideoInfoWindow(QMainWindow, Ui_VideoInfoWindow):
         """
         QMainWindow.__init__(self, parent)
         self.setAttribute(Qt.WA_Maemo5StackedWindow)
+        self.setAttribute(Qt.WA_Maemo5AutoOrientation, GeneralSettings.autoOrientation)
         self.setupUi(self)
         self.connect(QApplication.desktop(), SIGNAL("resized(int)"), self.orientationChanged)
         self.orientationChanged()
