@@ -148,6 +148,20 @@ class YouTubeDataService(object):
         except:
             videoEntry = YouTubeDataService.ytService.GetYouTubeVideoEntry(video_id = videoId)
         return videoEntry
+        
+    @staticmethod
+    def getVideoRestrictions(video):
+        """
+        Checks for any restrictions that may apply to the video.
+        """
+        restriction = None
+        try:
+            if video.control.FindExtensions()[0].text != "Syndication of this video was restricted by its owner.":
+                restriction = video.control.FindExtensions()[0].text
+                CutetubeLog.logException("Error retrieving %s: %s" % (video.media.title.text, restriction))
+        except:
+            restriction = None
+        return restriction
 
     @staticmethod
     def getVideoThumbnail(thumbUrl):
@@ -223,11 +237,13 @@ class YouTubeVideoFeed(QThread):
     Pulls the video feed from the YouTube server.
     """
 
-    def __init__(self, parent, videoFeed,  results = 0):
+    def __init__(self, parent, videoFeed):
         QThread.__init__(self, parent)
         self.videoFeed = videoFeed
         self.videoList = []
-        self.results = results
+        self.results = 0
+        self.thumbcount = 0
+        self.totalResults = 0
     
     def getVideoFeed(self):
         """
@@ -238,29 +254,49 @@ class YouTubeVideoFeed(QThread):
                 self.ytVideoFeed = YouTubeDataService.ytService.GetYouTubeVideoFeed(("%s?start-index=%d" % (self.videoFeed, self.results + 1)).encode("utf-8"))
             except:
                 self.ytVideoFeed = YouTubeDataService.ytService.GetYouTubeVideoFeed(("%s&start-index=%d" % (self.videoFeed, self.results + 1)).encode("utf-8"))
-        except gdata.service.RequestError, e:
+            self.totalResults = int(self.ytVideoFeed.total_results.text)
+        except Exception, e:
             CutetubeLog.logException("Unable to retrieve video feed. Trying again")
             try:
-                self.ytVideoFeed = YouTubeDataService.ytService.GetYouTubeVideoFeed(("%s?start-index=%d" % (self.videoFeed, self.results + 1)).encode("utf-8"))
-            except:
-                self.ytVideoFeed = YouTubeDataService.ytService.GetYouTubeVideoFeed(("%s&start-index=%d" % (self.videoFeed, self.results + 1)).encode("utf-8"))
+                try:
+                    self.ytVideoFeed = YouTubeDataService.ytService.GetYouTubeVideoFeed(("%s?start-index=%d" % (self.videoFeed, self.results + 1)).encode("utf-8"))
+                except:
+                    self.ytVideoFeed = YouTubeDataService.ytService.GetYouTubeVideoFeed(("%s&start-index=%d" % (self.videoFeed, self.results + 1)).encode("utf-8"))
+                self.totalResults = int(self.ytVideoFeed.total_results.text)
+            except Exception, e:
+                CutetubeLog.logException("Unable to retrieve video feed. Aborting: ")
             
     def getVideoData(self):
+        """
+        Returns the xml for each video.
+        """
         for video in self.ytVideoFeed.entry:
+            if YouTubeDataService.getVideoRestrictions(video) == None:
+                try:
+                    self.videoList.append(video)
+                    self.emit(SIGNAL("dataLoaded(PyQt_PyObject)"), video)
+                    self.results += 1
+                except Exception, e:
+                    CutetubeLog.logException("Unable to retrieve video entry: \'%s\': " % video.media.title.text)
+                
+    def getThumbnails(self):
+        """
+        Retrieves and returns the thumbnail for each video.
+        """
+        for video in self.videoList[self.thumbcount:]:
             try:
                 thumbnail = YouTubeDataService.getVideoThumbnail(video.media.thumbnail[3].url)
-                videoData = (video, thumbnail)
-                self.videoList.append(video)
-                self.emit(SIGNAL("dataLoaded(PyQt_PyObject)"), videoData)
-                self.results += 1
+                self.emit(SIGNAL("thumbnailLoaded(PyQt_PyObject)"), (self.thumbcount, thumbnail))
+                self.thumbcount += 1
             except Exception, e:
-                CutetubeLog.logException("Unable to retrieve video entry: \'%s\' (id = %s)" % (video.media.title.text, video.media.player.url.split("=") [1].split("&")[0]))
+                CutetubeLog.logException("Unable to retrieve thumbnail for: \'%s\': " % video.media.title.text)
 
     def run(self):
         self.emit(SIGNAL("feedCompleted(bool)"), True)
         self.getVideoFeed() 
         self.getVideoData()
         self.emit(SIGNAL("feedCompleted(bool)"), False)
+        self.getThumbnails()
 
 class YouTubeQueueFeed(QThread):
     """
@@ -278,14 +314,28 @@ class YouTubeQueueFeed(QThread):
         """
         for video in YouTubeQueueFeed.playlist:
             try:
-                thumbnail = YouTubeDataService.getVideoThumbnail(video.media.thumbnail[3].url)
-                videoData = (video, thumbnail)
-                self.emit(SIGNAL("dataLoaded(PyQt_PyObject)"), videoData)
+                self.emit(SIGNAL("dataLoaded(PyQt_PyObject)"), video)
             except:
                 pass
+                
+    def getThumbnails(self):
+        """
+        Retrieves and returns the thumbnail for each video.
+        """
+        row = 0
+        for video in YouTubeQueueFeed.playlist:
+            try:
+                thumbnail = YouTubeDataService.getVideoThumbnail(video.media.thumbnail[3].url)
+                self.emit(SIGNAL("thumbnailLoaded(PyQt_PyObject)"), (row, thumbnail))
+                row += 1
+            except Exception, e:
+                CutetubeLog.logException("Unable to retrieve thumbnail for: \'%s\': " % video.media.title.text)
 
     def run(self):
-        self.getQueueFeed() 
+        self.emit(SIGNAL("feedCompleted(bool)"), True)
+        self.getQueueFeed()
+        self.emit(SIGNAL("feedCompleted(bool)"), False)
+        self.getThumbnails()
 
 class YouTubeDownloadQueueFeed(QThread):
     """
@@ -301,14 +351,29 @@ class YouTubeDownloadQueueFeed(QThread):
         for task in YouTubeVideoDownloader.taskQueue:
             try:
                 video = task.video
-                thumbnail = YouTubeDataService.getVideoThumbnail(video.media.thumbnail[3].url)
-                videoData = (video, thumbnail)
-                self.emit(SIGNAL("dataLoaded(PyQt_PyObject)"), videoData)
+                self.emit(SIGNAL("dataLoaded(PyQt_PyObject)"), video)
             except:
                 pass
+                
+    def getThumbnails(self):
+        """
+        Retrieves and returns the thumbnail for each video.
+        """
+        row = 0
+        for task in YouTubeVideoDownloader.taskQueue:
+            try:
+                video = task.video
+                thumbnail = YouTubeDataService.getVideoThumbnail(video.media.thumbnail[3].url)
+                self.emit(SIGNAL("thumbnailLoaded(PyQt_PyObject)"), (row, thumbnail))
+                row += 1
+            except Exception, e:
+                CutetubeLog.logException("Unable to retrieve thumbnail for: \'%s\': " % video.media.title.text)
 
     def run(self):
+        self.emit(SIGNAL("feedCompleted(bool)"), True)
         self.getQueueFeed()
+        self.emit(SIGNAL("feedCompleted(bool)"), False)
+        self.getThumbnails()
 
 class YouTubePlaylistFeed(QThread):
     """
